==> php-nesbot-carbon_2.32.2.orig.tar.xz: php-nesbot-carbon-2.32.2/tests/Localization/HifTest.php <==
<?php
declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace Tests\Localization;

class HifTest extends LocalizationTestCase
{
    const LOCALE = 'hif'; // Fiji Hindi

    const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Shanivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Ravivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Somvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Budhvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        'Guruvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        'Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Budhvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Guruvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Shanivar at 12:00 Purvahan',
        // Carbon::now()->subDays(2)->calendar()
        'Last Ravivar at 8:49 Aparaahna',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 Aparaahna',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 Purvahan',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Somvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Ravivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Shanivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last Guruvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last Budhvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 2nd',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 purvahan CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 Purvahan, 12:00 purvahan',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 Purvahan, 1:30 purvahan',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 Purvahan, 2:00 purvahan',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 Purvahan, 6:00 purvahan',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 Purvahan, 10:00 purvahan',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 Aparaahna, 12:00 aparaahna',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 Aparaahna, 5:00 aparaahna',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 Aparaahna, 9:30 aparaahna',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 Aparaahna, 11:00 aparaahna',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 Second ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 Second ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 Second ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 Second ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 Minit ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1 Minit ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 Minit ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2 Minit ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 minit ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1 minit ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 minit ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2 minit ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 Din ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 Din ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 Din ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 Din ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 Hafta ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1 Hafta ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 Hafta ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2 Hafta ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 Mahina ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 Mahina ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 Mahina ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 Mahina ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 saal ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 saal ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 saal ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 saal ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 Second from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 Second from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 Second after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 Second after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 Second before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 Second before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 Second',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 Second',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 Second',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 Second',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 Second from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 Minit 1 Second',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 saal 3 Mahina 1 Din 1 Second',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 saal from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 Mahina ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 saal 3 Mahina 1 Din 1 Second ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 Hafta 10 minit',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 Hafta 6 Din',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 Hafta 6 Din',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 Hafta and 6 Din from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 Hafta 1 minit',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        '1 minit from now',
        // CarbonInterval::days(2)->forHumans()
        '2 Din',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 Din 3 minit',
    ];
}

==> php-nesbot-carbon_2.73.0.orig.tar.xz: php-nesbot-carbon-2.73.0/tests/Localization/HifTest.php <==
<?php

declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Tests\Localization;

/**
 * @group localization
 */
class HifTest extends LocalizationTestCase
{
    public const LOCALE = 'hif'; // Fiji Hindi

    public const CASES = [
        // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Tomorrow at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Shanivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Ravivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Somvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Budhvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
        'Guruvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
        'Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Budhvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Guruvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Shanivar at 12:00 Purvahan',
        // Carbon::now()->subDays(2)->calendar()
        'Last Ravivar at 8:49 Aparaahna',
        // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 10:00 Aparaahna',
        // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
        'Today at 10:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Today at 2:00 Purvahan',
        // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
        'Tomorrow at 1:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
        'Yesterday at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Yesterday at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Mangalvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Somvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Ravivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Shanivar at 12:00 Purvahan',
        // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
        'Last Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
        'Last Guruvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
        'Last Budhvar at 12:00 Purvahan',
        // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
        'Last Shukravar at 12:00 Purvahan',
        // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
        '1st 1st 1st 1st 1st',
        // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
        '2nd 1st',
        // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
        '3rd 1st',
        // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
        '4th 1st',
        // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
        '5th 1st',
        // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
        '6th 1st',
        // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
        '7th 2nd',
        // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
        '11th 2nd',
        // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
        '40th',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
        '41st',
        // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
        '100th',
        // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
        '12:00 purvahan CET',
        // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 Purvahan, 12:00 purvahan',
        // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
        '1:30 Purvahan, 1:30 purvahan',
        // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
        '2:00 Purvahan, 2:00 purvahan',
        // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
        '6:00 Purvahan, 6:00 purvahan',
        // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
        '10:00 Purvahan, 10:00 purvahan',
        // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
        '12:00 Aparaahna, 12:00 aparaahna',
        // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
        '5:00 Aparaahna, 5:00 aparaahna',
        // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
        '9:30 Aparaahna, 9:30 aparaahna',
        // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
        '11:00 Aparaahna, 11:00 aparaahna',
        // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
        '0th',
        // Carbon::now()->subSeconds(1)->diffForHumans()
        '1 Second ago',
        // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
        '1 Second ago',
        // Carbon::now()->subSeconds(2)->diffForHumans()
        '2 Second ago',
        // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
        '2 Second ago',
        // Carbon::now()->subMinutes(1)->diffForHumans()
        '1 Minit ago',
        // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
        '1 Minit ago',
        // Carbon::now()->subMinutes(2)->diffForHumans()
        '2 Minit ago',
        // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
        '2 Minit ago',
        // Carbon::now()->subHours(1)->diffForHumans()
        '1 minit ago',
        // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
        '1 minit ago',
        // Carbon::now()->subHours(2)->diffForHumans()
        '2 minit ago',
        // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
        '2 minit ago',
        // Carbon::now()->subDays(1)->diffForHumans()
        '1 Din ago',
        // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
        '1 Din ago',
        // Carbon::now()->subDays(2)->diffForHumans()
        '2 Din ago',
        // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
        '2 Din ago',
        // Carbon::now()->subWeeks(1)->diffForHumans()
        '1 Hafta ago',
        // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
        '1 Hafta ago',
        // Carbon::now()->subWeeks(2)->diffForHumans()
        '2 Hafta ago',
        // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
        '2 Hafta ago',
        // Carbon::now()->subMonths(1)->diffForHumans()
        '1 Mahina ago',
        // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
        '1 Mahina ago',
        // Carbon::now()->subMonths(2)->diffForHumans()
        '2 Mahina ago',
        // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
        '2 Mahina ago',
        // Carbon::now()->subYears(1)->diffForHumans()
        '1 saal ago',
        // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
        '1 saal ago',
        // Carbon::now()->subYears(2)->diffForHumans()
        '2 saal ago',
        // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
        '2 saal ago',
        // Carbon::now()->addSecond()->diffForHumans()
        '1 Second from now',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true)
        '1 Second from now',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
        '1 Second after',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
        '1 Second after',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
        '1 Second before',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
        '1 Second before',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
        '1 Second',
        // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
        '1 Second',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
        '2 Second',
        // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
        '2 Second',
        // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
        '1 Second from now',
        // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
        '1 Minit 1 Second',
        // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
        '2 saal 3 Mahina 1 Din 1 Second',
        // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
        '3 saal from now',
        // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
        '5 Mahina ago',
        // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
        '2 saal 3 Mahina 1 Din 1 Second ago',
        // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
        '1 Hafta 10 minit',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 Hafta 6 Din',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
        '1 Hafta 6 Din',
        // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
        '1 Hafta and 6 Din from now',
        // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
        '2 Hafta 1 minit',
        // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
        '1 minit from now',
        // CarbonInterval::days(2)->forHumans()
        '2 Din',
        // CarbonInterval::create('P1DT3H')->forHumans(true)
        '1 Din 3 minit',
    ];
}
